=====
Usage
=====

To launch RofiPaste from the command line simply type `rofipaste`
Once you've set your paste files, bind a keyboard shortcut to RofiPaste to access the content of your file from everywhere.